package model

import (
	"context"
	"gorm.io/gorm"
	"yx-dataset-server/app/errors"
	"yx-dataset-server/app/model/entity"
	"yx-dataset-server/app/schema"
)

// NewRobotConfig 创建RobotConfig存储实例
func NewRobotConfig(db *gorm.DB) *RobotConfig {
	return &RobotConfig{db}
}

// RobotConfig RobotConfig存储
type RobotConfig struct {
	db *gorm.DB
}

func (a *RobotConfig) getQueryOption(opts ...schema.RobotConfigQueryOptions) schema.RobotConfigQueryOptions {
	var opt schema.RobotConfigQueryOptions
	if len(opts) > 0 {
		opt = opts[0]
	}
	return opt
}

// Query 查询数据
func (a *RobotConfig) Query(ctx context.Context, params schema.RobotConfigQueryParam, opts ...schema.RobotConfigQueryOptions) (*schema.RobotConfigQueryResult, error) {
	db := entity.GetRobotConfigDB(ctx, a.db)
	if v := params.OrgId; v != "" {
		db = db.Where("org_id=?", v)
	}

	if v := params.UserId; v != "" {
		db = db.Where("creator_id=?", v)
	}

	// 根据回复类型过滤
	if params.ReplyType > 0 {
		db = db.Where("reply_type=?", params.ReplyType)
	}

	db = db.Order("id DESC")

	opt := a.getQueryOption(opts...)
	var list entity.RobotConfigs
	pr, err := WrapPageQuery(ctx, db, opt.PageParam, &list)
	if err != nil {
		return nil, errors.ErrDBServerInternalError
	}
	qr := &schema.RobotConfigQueryResult{
		PageResult: pr,
		Data:       list.ToSchemaRobotConfigs(),
	}

	return qr, nil
}

// Get 查询指定数据
func (a *RobotConfig) Get(ctx context.Context, recordID string, opts ...schema.RobotConfigQueryOptions) (*schema.RobotConfig, error) {
	db := entity.GetRobotConfigDB(ctx, a.db).Where("record_id=?", recordID)
	var item entity.RobotConfig
	ok, err := FindOne(ctx, db, &item)
	if err != nil {
		return nil, errors.ErrDBServerInternalError
	} else if !ok {
		return nil, nil
	}

	return item.ToSchemaRobotConfig(), nil
}

// Create 创建数据
func (a *RobotConfig) Create(ctx context.Context, item schema.RobotConfig) error {
	RobotConfig := entity.SchemaRobotConfig(item).ToRobotConfig()
	result := entity.GetRobotConfigDB(ctx, a.db).Create(RobotConfig)
	if err := result.Error; err != nil {
		return errors.ErrDBServerInternalError
	}
	return nil
}

// Update 更新数据
func (a *RobotConfig) Update(ctx context.Context, recordID string, item schema.RobotConfig) error {
	RobotConfig := entity.SchemaRobotConfig(item).ToRobotConfig()
	result := entity.GetRobotConfigDB(ctx, a.db).Where("record_id=?", recordID).Omit("record_id", "creator").Updates(RobotConfig)
	if err := result.Error; err != nil {
		return errors.ErrDBServerInternalError
	}
	return nil
}

// Delete 删除数据
func (a *RobotConfig) Delete(ctx context.Context, recordID string) error {
	result := entity.GetRobotConfigDB(ctx, a.db).Where("record_id=?", recordID).Delete(entity.RobotConfig{})
	if err := result.Error; err != nil {
		return errors.ErrDBServerInternalError
	}
	return nil
}

// UpdateStatus 更新状态
func (a *RobotConfig) UpdateStatus(ctx context.Context, recordID string, status int) error {
	result := entity.GetRobotConfigDB(ctx, a.db).Where("record_id=?", recordID).Update("status", status)
	if err := result.Error; err != nil {
		return errors.ErrDBServerInternalError
	}
	return nil
}
